<?php
// LOAD OMG CORE (if you remove this, the theme will break)
require_once( 'library/omg.php' );

// USE THIS TEMPLATE TO CREATE CUSTOM POST TYPES EASILY
//require_once( 'library/custom-post-type.php' );

// CUSTOMIZE THE WORDPRESS ADMIN (off by default)
// require_once( 'library/admin.php' );


function omgtheme_ahoy() {

  // let's get language support going, if you need it
  load_theme_textdomain( 'omgtheme', get_template_directory() . '/library/translation' );

  // launching operation cleanup
  add_action( 'init', 'omgtheme_head_cleanup' );
  // A better title
  add_filter( 'wp_title', 'rw_title', 10, 3 );
  // remove WP version from RSS
  add_filter( 'the_generator', 'omgtheme_rss_version' );
  // remove pesky injected css for recent comments widget
  add_filter( 'wp_head', 'omgtheme_remove_wp_widget_recent_comments_style', 1 );
  // clean up comment styles in the head
  add_action( 'wp_head', 'omgtheme_remove_recent_comments_style', 1 );
  // clean up gallery output in wp
  add_filter( 'gallery_style', 'omgtheme_gallery_style' );

  // enqueue base scripts and styles
  add_action( 'wp_enqueue_scripts', 'omgtheme_scripts_and_styles', 999 );
  // ie conditional wrapper

  // launching this stuff after theme setup
  omgtheme_theme_support();
  add_theme_support( 'custom-header' );
  // adding sidebars to Wordpress (these are created in functions.php)
  add_action( 'widgets_init', 'omgtheme_register_sidebars' );

  // cleaning up random code around images
  add_filter( 'the_content', 'omgtheme_filter_ptags_on_images' );
  // cleaning up excerpt
  add_filter( 'excerpt_more', 'omgtheme_excerpt_more' );

} /* end omg ahoy */

// let's get this party started
add_action( 'after_setup_theme', 'omgtheme_ahoy' );


/************* OEMBED SIZE OPTIONS *************/

if ( ! isset( $content_width ) ) {
  $content_width = 640;
}

/************* THUMBNAIL SIZE OPTIONS *************/

// Thumbnail sizes
add_image_size( 'omgtheme-thumb-600', 600, 150, true );
add_image_size( 'omgtheme-thumb-300', 300, 100, true );
add_image_size( 'slider-image', 1280, 500, true );
add_image_size( 'thumb-image-300by300', 300, 300, true );



add_filter( 'image_size_names_choose', 'omgtheme_custom_image_sizes' );
function omgtheme_custom_image_sizes( $sizes ) {
    return array_merge( $sizes, array(
        'omgtheme-thumb-600' => '600px by 150px',
        'omgtheme-thumb-300' => '300px by 100px',
        'slider-image' => '1280px by 500px'
    ) );
}

/*
The function above adds the ability to use the dropdown menu to select
the new images sizes you have just created from within the media manager
when you add media to your content blocks. If you add more image sizes,
duplicate one of the lines in the array and name it according to your
new image size.
*/

/************* ACTIVE SIDEBARS ********************/

// Sidebars & Widgetizes Areas
function omgtheme_register_sidebars() {
  register_sidebar(array(
    'id' => 'sidebar1',
    'name' => __( 'Posts Sidebar', 'omgtheme' ),
    'description' => __( 'The Posts sidebar.', 'omgtheme' ),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h4 class="widgettitle">',
    'after_title' => '</h4>',
  ));

  register_sidebar(array(
    'id' => 'sidebar2',
    'name' => __( 'Page Sidebar', 'omgtheme' ),
    'description' => __( 'The Page sidebar.', 'omgtheme' ),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h4 class="widgettitle">',
    'after_title' => '</h4>',
  ));

  register_sidebar(array(
    'id' => 'sidebar3',
    'name' => __( 'Menu Widget Area', 'omgtheme' ),
    'description' => __( 'The Menu Widget Area.', 'omgtheme' ),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h4 class="widgettitle">',
    'after_title' => '</h4>',
  ));


} // don't remove this bracket!


/************* COMMENT LAYOUT *********************/

// Comment Layout
function omgtheme_comments( $comment, $args, $depth ) {
   $GLOBALS['comment'] = $comment; ?>
  <div id="comment-<?php comment_ID(); ?>" <?php comment_class('cf'); ?>>
    <article  class="cf">
      <header class="comment-author vcard">
        <?php
        /*
          this is the new responsive optimized comment image. It used the new HTML5 data-attribute to display comment gravatars on larger screens only. What this means is that on larger posts, mobile sites don't have a ton of requests for comment images. This makes load time incredibly fast! If you'd like to change it back, just replace it with the regular wordpress gravatar call:
          echo get_avatar($comment,$size='32',$default='<path_to_url>' );
        */
        ?>
        <?php // custom gravatar call ?>
        <?php
          // create variable
          $bgauthemail = get_comment_author_email();
        ?>
        <img data-gravatar="http://www.gravatar.com/avatar/<?php echo md5( $bgauthemail ); ?>?s=100" class="load-gravatar avatar avatar-48 photo" height="100" width="100" src="<?php echo get_template_directory_uri(); ?>/library/images/nothing.gif" />
        <?php // end custom gravatar call ?>
      </header>
      <?php if ($comment->comment_approved == '0') : ?>
        <div class="alert alert-info">
          <p><?php _e( 'Your comment is awaiting moderation.', 'omgtheme' ) ?></p>
        </div>
      <?php endif; ?>
      <section class="comment_content cf">
        <?php printf(__( '<cite class="fn">%1$s</cite> %2$s', 'omgtheme' ), get_comment_author_link(), edit_comment_link(__( '(Edit)', 'omgtheme' ),'  ','') ) ?>
        <br>
        <time datetime="<?php echo comment_time('Y-m-j'); ?>"><a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>"><?php comment_time(__( 'F jS, Y', 'omgtheme' )); ?> </a></time>
        <?php comment_text() ?>
        <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
      </section>
    </article>
  <?php // </li> is added by WordPress automatically ?>
<?php
} // don't remove this bracket!



/*
This is a modification of a function found in the
twentythirteen theme where we can declare some
external fonts. If you're using Google Fonts, you
can replace these fonts, change it in your scss files
and be up and running in seconds.
*/
function omgtheme_fonts() {
  wp_register_style('googleFonts', 'http://fonts.googleapis.com/css?family=Lato:400,700,400italic,700italic');
  wp_enqueue_style( 'googleFonts');
}

add_action('wp_print_styles', 'omgtheme_fonts');

/*******************************************************************
* These are settings for the Theme Customizer in the admin panel. 
*******************************************************************/
if ( ! function_exists( 'omgtheme_theme_customizer' ) ) :
  function omgtheme_theme_customizer( $wp_customize ) {
    
    $wp_customize->remove_section( 'title_tagline');
    $wp_customize->remove_section( 'static_front_page' );
  
  
    /* color scheme option */
    $wp_customize->add_setting( 'omgtheme_color_settings', array (
      'default' => '#222222',
      'sanitize_callback' => 'sanitize_hex_color',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'omgtheme_color_settings', array(
      'label'    => __( 'Primary Color Scheme', 'OMG' ),
      'section'  => 'colors',
      'settings' => 'omgtheme_color_settings',
    ) ) );

    $wp_customize->add_setting( 'omgtheme_color_settings_2', array (
      'default' => '#656565',
      'sanitize_callback' => 'sanitize_hex_color',
    ) );

    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'omgtheme_color_settings_2', array(
      'label'    => __( 'Secondary Color Scheme', 'OMG' ),
      'section'  => 'colors',
      'settings' => 'omgtheme_color_settings_2',
    ) ) );

    $wp_customize->add_setting( 'omgtheme_color_settings_3', array (
      'default' => '#309DC1',
      'sanitize_callback' => 'sanitize_hex_color',
    ) );

    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'omgtheme_color_settings_3', array(
      'label'    => __( 'Button and link Color Scheme', 'OMG' ),
      'section'  => 'colors',
      'settings' => 'omgtheme_color_settings_3',
    ) ) );

    
    /* logo option */
    $wp_customize->add_section( 'omgtheme_logo_section' , array(
      'title'       => __( 'Site Logo', 'OMG' ),
      'priority'    => 1,
      'description' => __( 'Upload a logo to replace the default site name in the header', 'OMG' ),
    ) );
    
    $wp_customize->add_setting( 'omgtheme_logo', array(
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'omgtheme_logo', array(
      'label'    => __( 'Choose your logo (ideal width is 100-350px and ideal height is 35-40)', 'OMG' ),
      'section'  => 'omgtheme_logo_section',
      'settings' => 'omgtheme_logo',
    ) ) );
  
    /* favicon option */
    $wp_customize->add_section( 'omgtheme_favicon_section' , array(
      'title'       => __( 'Site favicon', 'OMG' ),
      'priority'    => 2,
      'description' => __( 'Upload a favicon', 'OMG' ),
    ) );
    
    $wp_customize->add_setting( 'omgtheme_favicon', array(
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'omgtheme_favicon', array(
      'label'    => __( 'Choose your favicon (ideal width and height is 16x16 or 32x32)', 'OMG' ),
      'section'  => 'omgtheme_favicon_section',
      'settings' => 'omgtheme_favicon',
    ) ) );
    
    /* social media option */
    $wp_customize->add_section( 'omgtheme_social_section' , array(
      'title'       => __( 'Social Media Icons', 'OMG' ),
      'priority'    => 32,
      'description' => __( 'Optional media icons in the header', 'OMG' ),
    ) );
    
    $wp_customize->add_setting( 'omgtheme_facebook', array (
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_facebook', array(
      'label'    => __( 'Enter your Facebook url', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_facebook',
      'priority'    => 101,
    ) ) );
  
    $wp_customize->add_setting( 'omgtheme_twitter', array (
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_twitter', array(
      'label'    => __( 'Enter your Twitter url', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_twitter',
      'priority'    => 102,
    ) ) );
    
    $wp_customize->add_setting( 'omgtheme_google', array (
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_google', array(
      'label'    => __( 'Enter your Google+ url', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_google',
      'priority'    => 103,
    ) ) );
    
    $wp_customize->add_setting( 'omgtheme_pinterest', array (
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_pinterest', array(
      'label'    => __( 'Enter your Pinterest url', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_pinterest',
      'priority'    => 104,
    ) ) );
    
    $wp_customize->add_setting( 'omgtheme_linkedin', array (
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_linkedin', array(
      'label'    => __( 'Enter your Linkedin url', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_linkedin',
      'priority'    => 105,
    ) ) );
    
    $wp_customize->add_setting( 'omgtheme_youtube', array (
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_youtube', array(
      'label'    => __( 'Enter your Youtube url', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_youtube',
      'priority'    => 106,
    ) ) );
    
    $wp_customize->add_setting( 'omgtheme_tumblr', array (
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_tumblr', array(
      'label'    => __( 'Enter your Tumblr url', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_tumblr',
      'priority'    => 107,
    ) ) );
    
    $wp_customize->add_setting( 'omgtheme_instagram', array (
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_instagram', array(
      'label'    => __( 'Enter your Instagram url', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_instagram',
      'priority'    => 108,
    ) ) );
    
    $wp_customize->add_setting( 'omgtheme_flickr', array (
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_flickr', array(
      'label'    => __( 'Enter your Flickr url', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_flickr',
      'priority'    => 109,
    ) ) );
    
    $wp_customize->add_setting( 'omgtheme_vimeo', array (
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_vimeo', array(
      'label'    => __( 'Enter your Vimeo url', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_vimeo',
      'priority'    => 110,
    ) ) );
    
    $wp_customize->add_setting( 'omgtheme_yelp', array (
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_yelp', array(
      'label'    => __( 'Enter your Yelp url', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_yelp',
      'priority'    => 111,
    ) ) );
    
    $wp_customize->add_setting( 'omgtheme_rss', array (
      'sanitize_callback' => 'esc_url_raw',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_rss', array(
      'label'    => __( 'Enter your RSS url', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_rss',
      'priority'    => 112,
    ) ) );
    
    $wp_customize->add_setting( 'omgtheme_email', array (
      'sanitize_callback' => 'sanitize_email',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_email', array(
      'label'    => __( 'Enter your email address', 'OMG' ),
      'section'  => 'omgtheme_social_section',
      'settings' => 'omgtheme_email',
      'priority'    => 113,
    ) ) );
    
    /* slider options */
    
    $wp_customize->add_section( 'omgtheme_slider_section' , array(
      'title'       => __( 'Slider Options', 'OMG' ),
      'priority'    => 33,
      'description' => __( 'Adjust the behavior of the image slider.', 'OMG' ),
    ) );
    
    $wp_customize->add_setting( 'omgtheme_slider_effect', array(
      'default' => 'scrollHorz',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'sanitize_text_field',
    ));
    
    $wp_customize->add_control( 'effect_select_box', array(
      'settings' => 'omgtheme_slider_effect',
      'label' => __( 'Select Effect:', 'OMG' ),
      'section' => 'omgtheme_slider_section',
      'type' => 'select',
      'choices' => array(
        'scrollHorz' => 'Horizontal (Default)',
        'scrollVert' => 'Vertical',
        'tileSlide' => 'Tile Slide',
        'tileBlind' => 'Blinds',
        'shuffle' => 'Shuffle',
      ),
    ));
    
    $wp_customize->add_setting( 'omgtheme_slider_timeout', array (
      'sanitize_callback' => 'omgtheme_sanitize_integer',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omgtheme_slider_timeout', array(
      'label'    => __( 'Autoplay Speed in Seconds', 'OMG' ),
      'section'  => 'omgtheme_slider_section',
      'settings' => 'omgtheme_slider_timeout',
    ) ) );

     /* author bio in posts option */
    $wp_customize->add_section( 'omgtheme_author_bio_section' , array(
      'title'       => __( 'Disable Author Bio', 'OMG' ),
      'priority'    => 35,
      'description' => __( 'Option to disable the author bio in the posts.', 'OMG' ),
    ) );
    
    $wp_customize->add_setting( 'omgtheme_author_bio', array (
      'sanitize_callback' => 'omgtheme_sanitize_checkbox',
    ) );
    
    $wp_customize->add_control('author_bio', array(
      'settings' => 'omgtheme_author_bio',
      'label' => __('Disable the Author Bio?', 'OMG'),
      'section' => 'omgtheme_author_bio_section',
      'type' => 'checkbox',
    ));

    /* related posts option */
    $wp_customize->add_section( 'omgtheme_related_posts_section' , array(
      'title'       => __( 'Disable Related Posts', 'OMG' ),
      'priority'    => 36,
      'description' => __( 'Option to disable the related posts in the posts.', 'OMG' ),
    ) );
    
    $wp_customize->add_setting( 'omgtheme_related_posts', array (
      'sanitize_callback' => 'omgtheme_sanitize_checkbox',
    ) );
    
    $wp_customize->add_control('related_posts', array(
      'settings' => 'omgtheme_related_posts',
      'label' => __('Disable the Related Posts?', 'OMG'),
      'section' => 'omgtheme_related_posts_section',
      'type' => 'checkbox',
    ));
    
    $wp_customize->remove_section( 'nav');
    $wp_customize->remove_section( 'header_image');
    $wp_customize->remove_section( 'background_image');
  
  }
endif;
add_action('customize_register', 'omgtheme_theme_customizer');


/**
 * Sanitize checkbox
 */
if ( ! function_exists( 'omgtheme_sanitize_checkbox' ) ) :
  function omgtheme_sanitize_checkbox( $input ) {
    if ( $input == 1 ) {
      return 1;
    } else {
      return '';
    }
  }
endif;


/**
 * Sanitize integer input
 */
if ( ! function_exists( 'omgtheme_sanitize_integer' ) ) :
  function omgtheme_sanitize_integer( $input ) {
    return absint($input);
  }
endif;
/**
* Apply Color Scheme
*/
if ( ! function_exists( 'omgtheme_apply_color' ) ) :
  function omgtheme_apply_color() {
    if ( get_theme_mod('omgtheme_color_settings') ) {
  ?>
  <style>
      .blog-list .item h2,.pagination .current,.article-header h1,body .info p.author,body .related h3, body #comments-title,body .related ul li .related-info h3
      ,body cite.fn,body .comment-reply-title,.sidebar .widgettitle,.sidebar .widget #wp-calendar td#today,article.archive .entry-content h3 a
      {color: <?php echo get_theme_mod('omgtheme_color_settings'); ?>;}
      body .pagination li:first-child {border: 2px solid <?php echo get_theme_mod('omgtheme_color_settings'); ?>;}
  </style>
  <?php
    }
     if ( get_theme_mod('omgtheme_color_settings_2') ) { ?>
     <style>
      .blog-list .item .excerpt p,.blog-list .item .date,.blog-list .item time,.entry-content p,body .byline,body .info p.author-desc,
       body .related ul li .related-info p,body .comment time a,body .comment_content p,#sidebar1 .widget ul li,body #sidebar1 a,#sideba1 .widget #wp-calendar td
      {color: <?php echo get_theme_mod('omgtheme_color_settings_2'); ?>;}
     </style>

    <?php }

    if ( get_theme_mod('omgtheme_color_settings_3') ) { ?>
      <style>
        .blog-list .item a.read-more,button, html input[type="button"], input[type="reset"], input[type="submit"],.widget #wp-calendar caption,.blue-btn, .comment-reply-link, #submit
        {background:<?php echo get_theme_mod('omgtheme_color_settings_3'); ?>; }
        .entry-content p a,body .pagination li a,.blog-list .item a[rel="author"],body .byline a,body .info p.author-desc a,
        body .related ul li a,body .comment-reply-link
        {color: <?php echo get_theme_mod('omgtheme_color_settings_3'); ?>;}
      </style>
    <?php }
    
  }
endif;
add_action( 'wp_head', 'omgtheme_apply_color' );
/*-----------------------------------------------------------------------------------*/
/* custom functions below */
/*-----------------------------------------------------------------------------------*/
define( 'NO_HEADER_TEXT', true );
define('THEMEURL', get_template_directory_uri());
define('IMAGES', THEMEURL.'/images'); 
define('JS', THEMEURL.'/js');
define('CSS', THEMEURL.'/css');

add_filter( 'post_thumbnail_html', 'omgtheme_remove_thumbnail_dimensions', 10, 3 );

function omgtheme_remove_thumbnail_dimensions( $html, $post_id, $post_image_id ) {
    $html = preg_replace( '/(width|height)=\"\d*\"\s/', "", $html );
    return $html;
}

function omgtheme_paginate() {
global $wp_query, $wp_rewrite;
$wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;

$pagination = array(
    'base' => @add_query_arg('page','%#%'),
    'format' => '',
    'total' => $wp_query->max_num_pages,
    'current' => $current,
    'show_all' => true,
    'type' => 'list',
    'next_text' => '&raquo;',
    'prev_text' => '&laquo;'
    );

if( $wp_rewrite->using_permalinks() )
    $pagination['base'] = user_trailingslashit( trailingslashit( remove_query_arg( 'page', get_pagenum_link( 1 ) ) ) . '?page=%#%/', 'paged' );

if( !empty($wp_query->query_vars['s']) )
    $pagination['add_args'] = array( 's' => get_query_var( 's' ) );

echo paginate_links( $pagination );
}
add_filter( 'the_content', 'remove_br_gallery', 11, 2);
function remove_br_gallery($output) {
    return preg_replace('/<br style=(.*)>/mi','',$output);
}

function omgtheme_author_excerpt() {
      $text_limit = 50; //Words to show in author bio excerpt
      $read_more  = "Read more"; //Read more text
      $end_of_txt = "...";
      $name_of_author = get_the_author();
      $url_of_author  = get_author_posts_url(get_the_author_meta('ID'));
      $short_desc_author = wp_trim_words(strip_tags(
                          get_the_author_meta('description')), $text_limit, 
                          $end_of_txt.'<br/>
                        <a href="'.$url_of_author.'" style="font-weight:bold;">'.$read_more .'</a>');

      return $short_desc_author;
   }
function omgtheme_catch_that_image() {
  global $post, $posts;
  $first_img = '';
  ob_start();
  ob_end_clean();
 $transformed_content = apply_filters('the_content',$post->post_content);
  if( $output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $transformed_content, $matches)){
  $first_img = $matches[1][0];
  }

  return $first_img;
}

/**
 * Include the TGM_Plugin_Activation class.
 */
require_once dirname( __FILE__ ) . '/library/class/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'omgtheme_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function omgtheme_register_required_plugins() {
 
    /**
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(
 
 
        // This is an example of how to include a plugin from the WordPress Plugin Repository.
        array(
            'name'      => 'Advanced Custom Fields',
            'slug'      => 'advanced-custom-fields',
            'required'  => false,
        ),
 
    );
 
    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => __( 'Install Required Plugins', 'tgmpa' ),
            'menu_title'                      => __( 'Install Plugins', 'tgmpa' ),
            'installing'                      => __( 'Installing Plugin: %s', 'tgmpa' ), // %s = plugin name.
            'oops'                            => __( 'Something went wrong with the plugin API.', 'tgmpa' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins' ),
            'return'                          => __( 'Return to Required Plugins Installer', 'tgmpa' ),
            'plugin_activated'                => __( 'Plugin activated successfully.', 'tgmpa' ),
            'complete'                        => __( 'All plugins installed and activated successfully. %s', 'tgmpa' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );
 
    tgmpa( $plugins, $config );
 
}
/* DON'T DELETE THIS CLOSING TAG */ ?>